@@ -6,6 +6,8 @@ fi
 echo "BPL binary ${BPLC} is used ..."
 
 dir=$(pwd)
+failed=0
+succeeded=0
 
 for i in $(find . -name \*.bpl); do
 
@@ -25,9 +27,11 @@ for i in $(find . -name \*.bpl); do
     ${call} ${file} < ${file%.bpl}.in > ${file%.bpl}.tmp 2>&1
     if diff -Nau ${file%.bpl}.out ${file%.bpl}.tmp > ${file%.bpl}.diff; then
 	echo "ok"
-	rm ${file%.bpl}.tmp
+        succeeded=$((${succeeded} + 1))
+        rm ${file%.bpl}.tmp
     else
 	echo "failed"
+	failed=$((${failed} + 1))
 	cat ${file%.bpl}.diff
     fi
     rm ${file%.bpl}.diff
@@ -35,4 +39,7 @@ for i in $(find . -name \*.bpl); do
     [ -z "$(cat ${file%.bpl}.in)" ] && rm ${file%.bpl}.in
     cd ${dir}
 
-done
\ No newline at end of file
+done
+
+echo "${failed} of $((succeeded + failed)) tests failed"
+
